@@ -2,33 +2,35 @@ OC.L10N.register(
     "notes",
     {
     "Notes" : "Noter",
+    "Create new note" : "Opret ny note",
     "Error" : "Fejl",
     "New note" : "Ny note",
-    "Undo Delete" : "Annullér Slet",
+    "Undo Delete" : "Annuller Slet",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Der er noter der ikke er gemt. Hvis du forlader denne side vil de blive smidt væk!",
-    "Display mode for notes" : "Visningstilstand for noter",
-    "Action" : "Handling",
     "Open in edit mode" : "Åbn i redigeringstilstand",
     "Open in preview mode" : "Åbn forhåndsvisning",
     "Insert image" : "Indsæt billede",
+    "File extension" : "Filendelse",
+    "Display mode for notes" : "Visningstilstand for noter",
+    "Action" : "Handling",
     "All notes" : "Alle noter",
     "Categories" : "Kategorier",
     "No notes yet" : "Ingen noter endnu",
+    "Remove from favorites" : "Fjern fra favoritter",
+    "Add to favorites" : "Føj til favoritter",
     "Share" : "Share",
     "Rename" : "Rename",
     "Delete note" : "Slet note",
-    "Remove from favorites" : "Fjernet fra favoritter",
-    "Add to favorites" : "Føj til favoritter",
     "Use current version" : "Brug aktuelle version",
-    "Edit" : "Redigér",
-    "Preview" : "Vis eksempel",
-    "Loading …" : "Indlæser…",
+    "Edit" : "Rediger",
+    "Preview" : "Forhåndsvis",
     "Today" : "I dag",
     "Yesterday" : "I går",
     "This week" : "Denne uge",
     "Last week" : "Sidste uge",
     "This month" : "Denne måned",
     "Last month" : "Seneste måned",
+    "Loading …" : "Indlæser…",
     "Uncategorized" : "Udenfor kategori",
     "Tasks" : "Opgaver"
 },
