@@ -2,22 +2,28 @@ OC.L10N.register(
     "notes",
     {
     "Notes" : "Piezīmes",
+    "More notes" : "Vairāk piezīmju",
     "Error" : "Kļūda",
     "New note" : "Jauna piezīme",
+    "Notes settings" : "Piezīmju iestatījumi",
     "Action" : "Darbība",
     "All notes" : "Visas piezīmes",
     "Categories" : "Kategorijas",
     "No notes yet" : "Nav nevienas piezīmes",
-    "Share" : "Koplietot",
-    "Delete note" : "Dzēst piezīmi",
     "Remove from favorites" : "Noņemt no izlases",
     "Add to favorites" : "Pievienot izlasei",
-    "Edit" : "Rediģēt",
+    "Share" : "Koplietot",
+    "Rename" : "Pārdēvēt",
+    "Delete note" : "Izdzēst piezīmi",
+    "Use version from server" : "Izmantot servera versiju",
+    "Use current version" : "Izmantot pašreizējo versiju",
+    "Edit" : "Labot",
     "Preview" : "Priekšskatīt",
     "Today" : "Šodien",
     "Yesterday" : "Vakar",
     "This week" : "Šonedēļ",
     "This month" : "Šis mēnesis",
+    "Loading …" : "Notiek ielāde ...",
     "Updating settings has failed." : "Iestatījumu atjaunināšana neizdevās.",
     "Uncategorized" : "Bez kategorijas",
     "Tasks" : "Uzdevumi"
