@@ -4,18 +4,39 @@ OC.L10N.register(
     "Notes" : "Заметки",
     "Create new note" : "Создать новую заметку",
     "More notes" : "Еще заметки",
-    "Reading notes from filesystem has failed." : "Чтение заметок из файловой системы не удалось",
+    "Reading notes from filesystem has failed." : "Не удалось чтение заметок из файловой системы.",
     "Error" : "Ошибка",
     "New note" : "Новая заметка",
     "Distraction-free notes and writing" : "Простые заметки и записки",
-    "Notes settings" : "Настройки заметок",
-    "Please see Nextcloud server log for details." : "Для получения подробной информации, пожалуйста, обратитесь к журналам сервера Nextcloud.",
     "Deleted {title}" : "Заметка {title} удалена",
+    "_Deleted {number} note_::_Deleted {number} notes_" : ["Удалена [number] заметка","Удалены [number] заметки","Удалено [number] заметок","Удалено [number] заметок"],
     "Undo Delete" : "Отменить удаление",
     "Note recovered" : "Заметка восстановлена",
+    "_Recovered {number} note_::_Recovered {number} notes_" : ["Восстановлена [number] заметка","Восстановлены [number] заметки","Восстановлено [number] заметок","Восстановлено [number] заметок"],
     "There are unsaved notes. Leaving the page will discard all changes!" : "Есть несохраненные заметки. Если покинуть страницу, все изменения будут утеряны.",
-    "_Deleted {number} note_::_Deleted {number} notes_" : ["Удалена [number] заметка","Удалено [number] заметки","Удалено [number] заметок","Удалено [number] заметок"],
-    "_Recovered {number} note_::_Recovered {number} notes_" : ["Восстановлена [number] заметка","Восстановлено [number] заметки","Восстановлено [number] заметок","Восстановлено [number] заметок"],
+    "Notes settings" : "Настройки заметок",
+    "Please see Nextcloud server log for details." : "Для получения подробной информации, пожалуйста, обратитесь к журналам сервера Nextcloud.",
+    "User defined" : "Определено пользователем",
+    "Open in rich text mode" : "Открыть в текстовом режиме",
+    "Open in edit mode" : "Открыть в режиме редактирования",
+    "Open in preview mode" : "Открыть в режиме просмотра",
+    "CTRL" : "CTRL",
+    "Make the selection bold" : "Сделайте выделение жирным",
+    "Make the selection italic" : "Сделайте выделение курсивом",
+    "Wrap the selection in quotes" : "Заключите выделение в кавычки",
+    "ALT" : "ALT",
+    "The selection will be turned into monospace" : "Выделение будет переведено в моноширинный режим",
+    "Remove any styles from the selected text" : "Убрать все стили с выделенного текста",
+    "Makes the current line a list element" : "Делает текущую строку элементом списка",
+    "Makes the current line a list element with a number" : "Делает текущую строку элементом списка с номером",
+    "Toggle heading for current line" : "Переключить заголовок для текущей строки",
+    "SHIFT" : "СДВИГ",
+    "Set the current line as a big heading" : "Установите текущую строку как большой заголовок",
+    "Insert link" : "Вставить ссылку",
+    "Insert image" : "Вставить изображение",
+    "Switch between editor and viewer" : "Переключиться между редактированием и просмотром",
+    "Pick a notes folder" : "Выберите папку для заметок",
+    "Set notes folder" : "Установить папку для заметок",
     "Basics" : "Основные",
     "Write down your thoughts without any distractions." : "Записывайте свои мысли, ни на что не отвлекаясь.",
     "Organize your notes in categories." : "Поддержка категорий;",
@@ -31,32 +52,33 @@ OC.L10N.register(
     "Shortcut" : "Горячая клавиша",
     "Action" : "Действие",
     "Mobile apps" : "Мобильные приложения",
-    "User defined" : "Определено пользователем",
-    "Open in rich text mode" : "Открыть в текстовом режиме",
-    "Open in edit mode" : "Открыть в режиме редактирования",
-    "Open in preview mode" : "Открыть в режиме просмотра",
-    "CTRL" : "CTRL",
-    "Make the selection bold" : "Сделайте выделение жирным",
-    "Make the selection italic" : "Сделайте выделение курсивом",
-    "Wrap the selection in quotes" : "Заключите выделение в кавычки",
-    "ALT" : "ALT",
-    "Insert link" : "Вставить ссылку",
-    "Insert image" : "Вставить изображение",
-    "Switch between editor and viewer" : "Переключиться между редактированием и просмотром",
     "All notes" : "Все заметки",
     "Categories" : "Категории",
+    "Create a sample note with Markdown" : "Создайте образец заметки с помощью Markdown",
     "No notes yet" : "Нет ни одной заметки",
-    "Upload image" : "Загрузить изображение",
     "Select an image" : "Выберите изображение",
     "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Вы не можете выбрать изображения вне папки заметок. Ваша папка заметок: {папка}",
     "Wrong image" : "Неверное изображение",
     "The file was not uploaded. Check your server logs." : "Файл не был загружен. Проверьте журналы вашего сервера.",
+    "Upload image" : "Загрузить изображение",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "Для доступа к заметкам с телефона установите мобильное приложение.",
-    "Share" : "Публикация",
-    "Delete note" : "Удалить заметку",
+    "Android app: {notes}" : "Android приложение: {notes}",
+    "iOS app: {notes}" : "iOS приложение: {notes}",
+    "Rich text editor" : "Редактор форматированного текста",
+    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "Теперь вы можете переключиться на использование простого в использовании и свободного от отвлекающих факторов редактора форматированного текста. Он позволяет вам редактировать заметки, не видя разметки Markdown.",
+    "This option can also be changed later on in the Notes app settings." : "Эту настройку также можно изменить позже в настройках приложения \"Заметки\".",
+    "Keep plain Markdown editor" : "Сохраните простой редактор Markdown",
+    "Use rich editor" : "Использовать расширенный редактор",
     "Remove from favorites" : "Убрать из избранного",
     "Add to favorites" : "Добавить в избранное",
+    "Error while renaming note." : "Ошибка при переименовании заметки.",
     "Error during preparing note for deletion." : "Не удалось подготовить заметку к удалению,",
+    "Share" : "Публикация",
+    "Change category" : "Изменить категорию",
+    "Rename" : "Переименовать",
+    "Rename note" : "Переименовать заметку",
+    "Delete note" : "Удалить заметку",
+    "Error from Nextcloud server: {msg}" : "Ошибка сервера Nextcloud: {msg}",
     "The note has been changed in another session. Please choose which version should be saved." : "Данная заметка была изменена в другой сессии. Пожалуйста, выберите, какую версию сохранить.",
     "Use version from server" : "Использовать версию с сервера",
     "Use current version" : "Использовать текущую версию",
@@ -70,39 +92,51 @@ OC.L10N.register(
     "Note is read-only. You cannot change it." : "Заметка только для чтения. Вы не можете изменить её.",
     "Save failed. Click to retry." : "Сохранение не удалось. Нажмите для повтора.",
     "Update conflict. Click for resolving manually." : "Конфликт обновления. Щелкните для разрешения вручную.",
-    "Error from Nextcloud server: {msg}" : "Ошибка сервера Nextcloud: {msg}",
-    "Search for notes" : "Поиск заметок",
-    "Loading …" : "Загрузка ...",
-    "Find in all categories" : "Найти во всех категориях",
     "Today" : "Сегодня",
     "Yesterday" : "Вчера",
     "This week" : "Эта неделя",
     "Last week" : "За последнюю неделю",
     "This month" : "Этот месяц",
     "Last month" : "За последний месяц",
+    "Search for notes" : "Поиск заметок",
+    "Loading …" : "Загрузка ...",
+    "Find in all categories" : "Найти во всех категориях",
     "Use Markdown markups to style your text." : "Поддержка языка разметки Markdown для оформления текста;",
     "Start writing a note by clicking on “{newnote}” in the app navigation." : "Чтобы создать заметку, нажмите «{newnote}» в панели навигации.",
     "Note not found." : "Заметка не найдена",
     "Note is locked." : "Заметка заблокирована",
-    "Insufficient storage." : "Ндостаточно места",
+    "Insufficient storage." : "Недостаточно места",
     "See JavaScript console and server log for details." : "Подробные сведения приведены в консоли JavaScript и файле журнала сервера.",
     "Updating settings has failed." : "Не удалось сохранить изменения.",
-    "Fetching notes for dashboard has failed." : "Загрузка заметок на панель не удалось.",
+    "Fetching notes for dashboard has failed." : "Не удалось получить заметки для панели.",
     "Fetching notes has failed." : "Не удалось получить заметки.",
     "Fetching note {id} has failed." : "Не удалось получить заметку {id}.",
-    "Refreshing note {id} has failed." : "Обновление заметки {id} не удалось",
+    "Refreshing note {id} has failed." : "Не удалось обновить заметку {id}.",
     "Renaming note {id} has failed." : "Не удалось переименовать заметку {id}.",
     "Creating new note has failed." : "Не удалось создать заметку.",
-    "Saving note {id} has failed." : "Сохранение заметки {id} не удалось",
-    "Updating title for note {id} has failed." : "Обновление заголовка для заметки {id} не удалось",
+    "Saving note {id} has failed." : "Не удалось сохранить заметку {id}.",
+    "Updating title for note {id} has failed." : "Не удалось обновление заголовка для заметки {id}.",
     "Undo delete has failed for note {title}." : "Не удалось отменить удаление заметки {title}.",
     "Deleting note {id} has failed." : "Не удалось удалить заметку {id}.",
     "Toggling favorite for note {id} has failed." : "Не удалось установить отметку «избранное» для заметки {id}.",
-    "Updating the note's category has failed. Is the target directory writable?" : "Ошибка обновления категории заметки. Разрешена ли запись в целевую директорию?",
+    "Updating the note's category has failed. Is the target directory writable?" : "Не удалось обновить категорию заметки. Разрешена ли запись в целевую директорию?",
     "Updating the category for note {id} has failed." : "Не удалось обновить категорию для заметки {id}.",
     "Uncategorized" : "Без категории",
     "Sample note" : "Пример заметки",
+    "15 January 2021, via Nextcloud Notes" : "15 января 2021 г., через Nextcloud Notes",
+    "Me, you, and all our friends!" : "Я, ты и все наши друзья!",
     "Tasks" : "Задачи",
+    "Write nice todo lists" : "Напишите хорошие списки дел",
+    "Buy Fries" : "Купить картофель фри",
+    "Birthdays" : "Дни рождения",
+    "Jen, in three days!" : "Джен, через три дня!",
+    "Moss, 21.03.1973" : "Мосс, 21.03.1973",
+    "Roy, 1979" : "Рой, 1979",
+    "Review Steps" : "Обзор шагов",
+    "Turn PC off" : "Выключить ПК",
+    "Turn PC on" : "Включить ПК",
+    "Then call IT" : "Тогда позвоните в ИТ-отдел",
+    "Quotes" : "Кавычки",
     "Nextcloud, a safe home for all your data" : "Nextcloud — безопасное место для всех ваших данных",
     "Development Mode" : "Режим разработки",
     "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Вероятно, это приложение было установлено из источника, предназначенного для разработчиков. Настоятельно рекомендуется переустановить его из официального <a href=\"%1$s\">каталога приложений Nextcloud</a>. Инструкции по самостоятельной сборке приложения приведены в  <a href=\"%2$s\">руководстве для разработчиков</a>."
