@@ -8,29 +8,14 @@ OC.L10N.register(
     "Error" : "Помилка",
     "New note" : "Нова нотатка",
     "Distraction-free notes and writing" : "Нотатки та записи без відволікань",
-    "Notes settings" : "Налаштування",
-    "Please see Nextcloud server log for details." : "Будь ласка, перегляньте журнал сервера хмари Nextcloud для отримання додаткової інформації.",
     "Deleted {title}" : "Вилучено {title}",
+    "_Deleted {number} note_::_Deleted {number} notes_" : ["Вилучено {number} нотатку","Вилучено {number} нотатки","Вилучено {number} нотаток","Вилучено {number} нотаток"],
     "Undo Delete" : "Повернути вилучення",
     "Note recovered" : "Примітку відновлено",
-    "There are unsaved notes. Leaving the page will discard all changes!" : "Є незбережені нотатки. Якщо залишити сторінку, усі зміни буде скасовано!",
-    "_Deleted {number} note_::_Deleted {number} notes_" : ["Вилучено {number} нотатку","Вилучено {number} нотатки","Вилучено {number} нотаток","Вилучено {number} нотаток"],
     "_Recovered {number} note_::_Recovered {number} notes_" : ["Відновлено {number} нотатку","Відновлено {number} нотаток","Відновлено {number} нотаток","Відновлено {number} нотаток"],
-    "Basics" : "Простий",
-    "Write down your thoughts without any distractions." : "Занотовуйте свої думки, не відволікаючись.",
-    "Organize your notes in categories." : "Упорядкуйте нотатки за категоріями.",
-    "Notes path" : "Шлях до нотаток",
-    "Folder to store your notes" : "Каталог для збереження нотаток",
-    "Root directory" : "Кореневий каталог",
-    "File extension" : "Розширення файлу",
-    "File extension for new notes" : "Розширення файлу для нових нотаток",
-    "Display mode" : "Режим перегляду",
-    "Display mode for notes" : "Показувати нотатки",
-    "Shortcuts" : "Скорочення",
-    "Use shortcuts to quickly navigate this app." : "Використовуйте скорочення для швидкої навігації у цьому застосунку.",
-    "Shortcut" : "Скорочення",
-    "Action" : "Дія ",
-    "Mobile apps" : "Застосунки",
+    "There are unsaved notes. Leaving the page will discard all changes!" : "Є незбережені нотатки. Якщо залишити сторінку, усі зміни буде скасовано!",
+    "Notes settings" : "Налаштування",
+    "Please see Nextcloud server log for details." : "Будь ласка, перегляньте журнал сервера хмари Nextcloud для отримання додаткової інформації.",
     "User defined" : "Визначений користувачем",
     "Open in rich text mode" : "Відкривати у форматі текстової розмітки",
     "Open in edit mode" : "Відкривати у режимі редагування",
@@ -50,16 +35,32 @@ OC.L10N.register(
     "Insert link" : "Вставити посилання",
     "Insert image" : "Додати зображення",
     "Switch between editor and viewer" : "Перемкнути редактор та переглядач",
-    "Select folder to link to" : "Виберіть каталог",
+    "Pick a notes folder" : "Виберіть каталог для нотаток",
+    "Set notes folder" : "Встановити каталог для нотаток",
+    "Basics" : "Основне",
+    "Write down your thoughts without any distractions." : "Занотовуйте свої думки, не відволікаючись.",
+    "Organize your notes in categories." : "Упорядкуйте нотатки за категоріями.",
+    "Notes path" : "Шлях до нотаток",
+    "Folder to store your notes" : "Каталог для збереження нотаток",
+    "Root directory" : "Кореневий каталог",
+    "File extension" : "Розширення",
+    "File extension for new notes" : "Типове розширення файлу для нових нотаток",
+    "Display mode" : "Режим перегляду",
+    "Display mode for notes" : "Показувати нотатки",
+    "Shortcuts" : "Скорочення",
+    "Use shortcuts to quickly navigate this app." : "Використовуйте скорочення для швидкої навігації у цьому застосунку.",
+    "Shortcut" : "Скорочення",
+    "Action" : "Дія ",
+    "Mobile apps" : "Застосунки",
     "All notes" : "Усі нотатки",
     "Categories" : "Категорії",
     "Create a sample note with Markdown" : "Створіть зразок примітки з використанням текстової розмітки",
     "No notes yet" : "Нотатки поки відсутні",
-    "Upload image" : "Завантажити зображення",
     "Select an image" : "Виберіть зображення",
     "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Ви не можете вибрати зображення за межами каталогу з нотатками. Ваш каталог нотаток: {folder}",
     "Wrong image" : "Недійсне зображення",
     "The file was not uploaded. Check your server logs." : "Файл не було завантажено. Перевірте журнали сервера.",
+    "Upload image" : "Завантажити зображення",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "Встановіть мобільний застосунок для мобільного телефону, що дозволить отримувати доступ до нотаток звідусіль.",
     "Android app: {notes}" : "Застосунок для Android: {notes}",
     "iOS app: {notes}" : "Застосунок для iOS: {notes}",
@@ -68,15 +69,16 @@ OC.L10N.register(
     "This option can also be changed later on in the Notes app settings." : "Цю опцію можна буде змінити пізніше у налаштуваннях Нотаток.",
     "Keep plain Markdown editor" : "Використовувати простий редактор розмітки",
     "Use rich editor" : "Використовувати редактор з форматуванням",
+    "Remove from favorites" : "Прибрати зірочку",
+    "Add to favorites" : "Додати зірочку",
+    "Error while renaming note." : "Помилка під час перейменування нотатки.",
+    "Error during preparing note for deletion." : "Помилка під час підготовки нотатки до вилучення.",
     "Share" : "Поділитися",
     "Change category" : "Змінити категорію",
     "Rename" : "Перейменувати",
     "Rename note" : "Перейменувати нотатку",
     "Delete note" : "Вилучити",
-    "Remove from favorites" : "Прибрати зірочку",
-    "Add to favorites" : "Додати зірочку",
-    "Error while renaming note." : "Помилка під час перейменування нотатки.",
-    "Error during preparing note for deletion." : "Помилка під час підготовки нотатки до вилучення.",
+    "Error from Nextcloud server: {msg}" : "Помилка сервера Nextcloud: {msg}",
     "The note has been changed in another session. Please choose which version should be saved." : "Нотатку було змінено в іншому сеансі. Будь ласка, виберіть, яку версію потрібно зберегти.",
     "Use version from server" : "Використовувати віддалену версію",
     "Use current version" : "Використовувати поточну версію",
@@ -90,16 +92,15 @@ OC.L10N.register(
     "Note is read-only. You cannot change it." : "Нотатка доступна лише для читання. Ви не можете це змінити.",
     "Save failed. Click to retry." : "Не вдалося зберегти. Клацніть, щоб повторити спробу.",
     "Update conflict. Click for resolving manually." : "Конфлікт під час оновлення. Клацніть, щоб прийняти рішення вручну.",
-    "Error from Nextcloud server: {msg}" : "Помилка сервера Nextcloud: {msg}",
-    "Search for notes" : "Пошук нотаток",
-    "Loading …" : "Завантаження ...",
-    "Find in all categories" : "Шукати в усіх категоріях",
     "Today" : "Сьогодні",
     "Yesterday" : "Вчора",
     "This week" : "Цього тижня",
     "Last week" : "Минулого тижня",
     "This month" : "Цього місяця",
     "Last month" : "Минулого місяця",
+    "Search for notes" : "Пошук нотаток",
+    "Loading …" : "Завантаження ...",
+    "Find in all categories" : "Шукати в усіх категоріях",
     "Use Markdown markups to style your text." : "Використовувати текстову розмітку для стилізації тексту.",
     "Start writing a note by clicking on “{newnote}” in the app navigation." : "Почніть писати нотатку, для цього виберіть \"{newnote}\" ​​у навігаційній панелі застосунку.",
     "Note not found." : "Нотатку не знайдено.",
