@@ -2,6 +2,11 @@
 
 declare(strict_types=1);
 
+/**
+ * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
+ */
+
 namespace OCA\Notes\Service;
 
 use OCP\Files\File;
@@ -30,7 +35,7 @@ class NoteUtil {
 		TagService $tagService,
 		IManager $shareManager,
 		IUserSession $userSession,
-		SettingsService $settingsService
+		SettingsService $settingsService,
 	) {
 		$this->util = $util;
 		$this->root = $root;
@@ -62,7 +67,7 @@ class NoteUtil {
 		$cats = array_filter($cats, function ($str) {
 			return $str !== '';
 		});
-		$path .= '/'.implode('/', $cats);
+		$path .= '/' . implode('/', $cats);
 		return $this->getOrCreateFolder($path);
 	}
 
@@ -172,12 +177,24 @@ class NoteUtil {
 		}
 
 		if (!($folder instanceof Folder)) {
-			throw new NotesFolderException($path.' is not a folder');
+			throw new NotesFolderException($path . ' is not a folder');
 		}
 
 		return $folder;
 	}
 
+	public function getNotesFolderUserPath(string $userId): ?string {
+		/** @psalm-suppress MissingDependency */
+		$userFolder = $this->getRoot()->getUserFolder($userId);
+		try {
+			$nodesFolder = $this->getOrCreateNotesFolder($userId, false);
+		} catch (NotesFolderException $e) {
+			$this->util->logger->warning("Failed to get notes folder for user $userId: " . $e->getMessage());
+			return null;
+		}
+		return $userFolder->getRelativePath($nodesFolder->getPath());
+	}
+
 	public function getOrCreateNotesFolder(string $userId, bool $create = true) : Folder {
 		$userFolder = $this->getRoot()->getUserFolder($userId);
 		$notesPath = $this->settingsService->get($userId, 'notesPath');
@@ -220,7 +237,7 @@ class NoteUtil {
 		$isEmpty = !count($content);
 		$isNotesFolder = $folder->getPath() === $notesFolder->getPath();
 		if ($isEmpty && !$isNotesFolder) {
-			$this->util->logger->debug('Deleting empty category folder '.$folder->getPath());
+			$this->util->logger->debug('Deleting empty category folder ' . $folder->getPath());
 			$parent = $folder->getParent();
 			$folder->delete();
 			$this->deleteEmptyFolder($parent, $notesFolder);
@@ -237,11 +254,11 @@ class NoteUtil {
 		$availableBytes = $folder->getFreeSpace();
 		if ($availableBytes >= 0 && $availableBytes < $requiredBytes) {
 			$this->util->logger->error(
-				'Insufficient storage in '.$folder->getPath().': '.
-				'available are '.$availableBytes.'; '.
-				'required are '.$requiredBytes
+				'Insufficient storage in ' . $folder->getPath() . ': ' .
+				'available are ' . $availableBytes . '; ' .
+				'required are ' . $requiredBytes
 			);
-			throw new InsufficientStorageException($requiredBytes.' are required in '.$folder->getPath());
+			throw new InsufficientStorageException($requiredBytes . ' are required in ' . $folder->getPath());
 		}
 	}
 
