@@ -2,6 +2,11 @@
 
 declare(strict_types=1);
 
+/**
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
+ */
+
 namespace OCA\Notes\Service;
 
 use OCA\Notes\AppInfo\Application;
@@ -26,7 +31,7 @@ class SettingsService {
 		IConfig $config,
 		IL10N $l10n,
 		IRootFolder $root,
-		IAppManager $appManager
+		IAppManager $appManager,
 	) {
 		$this->config = $config;
 		$this->l10n = $l10n;
@@ -169,7 +174,7 @@ class SettingsService {
 		if (property_exists($settings, $name)) {
 			return $settings->{$name};
 		} else {
-			throw new \OCP\PreConditionNotMetException('Setting '.$name.' not found for user '.$uid.'.');
+			throw new \OCP\PreConditionNotMetException('Setting ' . $name . ' not found for user ' . $uid . '.');
 		}
 	}
 
